==> l10n-1.2.2.tar.gz: lib/parser/tools.dart <==
/*
 * Copyright (c) 2017, Michael Mitterer (office@mikemitterer.at),
 * IT-Consulting and Development Limited.
 *
 * All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

part of l10n.parser;

class CharacterType {
    static bool isLetterOrDigit(final String char) {
        Validate.notNull(char);
        Validate.isTrue(char.isNotEmpty && char.length == 1);

        final RegExp regexp = new RegExp(r"^[0-9,a-z]$",caseSensitive: false);
        return regexp.hasMatch(char);
    }

    static bool isLetter(final String char) {
        Validate.notNull(char);
        Validate.isTrue(char.isNotEmpty && char.length == 1);

        final RegExp regexp = new RegExp(r"^[a-z]$",caseSensitive: false);
        return regexp.hasMatch(char);
    }

    static bool isDigit(final String char) {
        Validate.notNull(char);
        Validate.isTrue(char.isNotEmpty && char.length == 1);

        final RegExp regexp = new RegExp(r"^[0-9]$");
        return regexp.hasMatch(char);
    }
}

==> l10n-2.0.15.tar.gz: lib/parser/tools.dart <==
/*
 * Copyright (c) 2017, Michael Mitterer (office@mikemitterer.at),
 * IT-Consulting and Development Limited.
 *
 * All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

part of l10n.parser;

class CharacterType {
    static bool isLetterOrDigit(final String char) {
        Validate.notNull(char);
        Validate.isTrue(char.isNotEmpty && char.length == 1);

        final RegExp regexp = new RegExp(r"^[0-9,a-z]$",caseSensitive: false);
        return regexp.hasMatch(char);
    }

    static bool isLetter(final String char) {
        Validate.notNull(char);
        Validate.isTrue(char.isNotEmpty && char.length == 1);

        final RegExp regexp = new RegExp(r"^[a-z]$",caseSensitive: false);
        return regexp.hasMatch(char);
    }

    /// . is also treated as Digit
    static bool isDigit(final String char) {
        Validate.notNull(char);
        Validate.isTrue(char.isNotEmpty && char.length == 1);

        final RegExp regexp = new RegExp(r"^[0-9.]$");
        return regexp.hasMatch(char);
    }
}
